@@ -17,6 +17,8 @@ def parser_args():
     parser.add_argument('--output-format', type=str, help="输出功能格式，有labelme、coco")
     parser.add_argument('-f', '--function', type=str, required=True, help="功能参数:print,convert,filter,matting,rename,visualize,merge，只能输入单个")
     parser.add_argument('--filter-label', type=ast.literal_eval, help="类别筛选参数，单个与多个都可以输入")
+    parser.add_argument('--exclude-if-only', type=ast.literal_eval, help="标签采样参数，排除某些标签为主的图片（即不希望看到的标签）")
+    parser.add_argument('--include-focus', type=ast.literal_eval, help="标签采样参数，优先采集某些标签（即重点采集的标签）")
     # 当不输入--only_annotation，默认为False；输入--only_annotation，才会触发True值。False处理labelme和图片，True只处理labelme
     parser.add_argument('--only-annotation', action="store_true", help="默认False，是否只处理注释文件。是为True，否为False")
     parser.add_argument('--filter-shape-type', type=ast.literal_eval, help="形状筛选参数，单个与多个都可以输入")
@@ -26,22 +28,34 @@ def parser_args():
     parser.add_argument('--only-select-empty', action="store_true", help="默认False，是否只筛选背景数据。是为True，否为False")
     parser.add_argument('--only-select-shapes', action="store_true", help="默认False，是否只筛选标注有框的数据。是为True，否为False")
     parser.add_argument('--shapes-attribute', type=str, help="筛选属性，包含label（类别）、shape_type（类别形状）、flags（类别属性）")
-    parser.add_argument('--filter-flags', type=ast.literal_eval, help="类别属性筛选，输入类别属性字典列表。比如person类下有，手、脚、头")
-    parser.add_argument('--file-formats', default=['.jpg', '.jpeg', '.png', '.JPEG', '.JPG', '.PNG', '.webp'], type=str,
+    parser.add_argument('--filter-flags', type=ast.literal_eval, help="类别属性筛选，输入类别属性字典列表。比如person类下有，告警图片地址")
+    parser.add_argument('--polygonVertex', type=ast.literal_eval, help="输入多边形列表坐标")
+    parser.add_argument('--columns-fill', type=ast.literal_eval, help="输入except表格列号，列表")
+    parser.add_argument('--column-titles', type=ast.literal_eval, help="输入except表格列号对应的标题")
+    parser.add_argument('--column-content-type', type=ast.literal_eval, help="输入except表格列号，字典")
+    parser.add_argument('--column-name', type=ast.literal_eval, help="excel表格列属性筛选，输入列名称。比如：视频源地址，手、脚、头")
+    parser.add_argument('--algorithm-type', type=ast.literal_eval, help="算法类型筛选，输入算法类型名称。比如：安全帽，抽烟，区域入侵，烟雾")
+    parser.add_argument('--file-formats', default=['.jpg', '.jpeg', '.png', '.JPEG', '.JPG', '.PNG', '.webp', '.bmp'], type=ast.literal_eval,
                         help="文件格式,其中,'.bmp','.gif','.tif',格式图像不做处理")
     parser.add_argument('--filter-combin', action="store_true", help="是否组合筛选，是为True，否为False")
     parser.add_argument('--extract-portion', type=int, help='按照指定份数平均抽取，比如400张图像，抽取10分，每份40张')
+    parser.add_argument('--fps', type=int, help='视频每秒钟展示的帧数')
     parser.add_argument('--extract-text', type=ast.literal_eval, help='按照text字段的文本内容抽取')
-    parser.add_argument('--select-cut', action="store_true", help="默认False即拷贝，是拷贝还是剪切。是为True，否为False")
+    parser.add_argument('--select-cut', action="store_true", help="默认False即拷贝，是拷贝还是剪切。是为True移动，否为False拷贝")
     parser.add_argument('--judging-group-id-num', action="store_true", help="默认False即拷贝，有judging-group-id-num参则改变为True，否为False")
     parser.add_argument('--extract-amount', type=int, help='按照指定数量抽取，比如400张图像，抽取100张')
     parser.add_argument('--print-more', action="store_true", help="打印详细信息")
     parser.add_argument('--del-label', type=ast.literal_eval, help="删除label标签")
+    parser.add_argument('--filter-polygon', type=ast.literal_eval, help="多边形列表")
     parser.add_argument('--judging-letter', type=ast.literal_eval, help="判断车牌字符串中是否存在，I，o,Q")
+    parser.add_argument('--contained-of-object', type=ast.literal_eval, help="填写被截取目标框包含的标签名称")
     parser.add_argument('--label-name', type=str, help="自定义label标签，用于抽取份数时区别标注目录")
+    parser.add_argument('--time', type=str, help="自定义时间段字符串")
     parser.add_argument('--http-url', type=str, help="minio文件对象存储中，网络文件统一资源定位器，http://192.168.1.235:9393/chipeak-dataset")
     parser.add_argument('--min-pixel', type=int, default=512, help='最小像素截图设置，默认512像素。即大于512像素的矩形框才进行截图')
     parser.add_argument('--judging-group', type=int, help='默认值为2个shape元素为一组，用于判断分组元素的数量')
+    parser.add_argument('--epsilon', type=float, default=2,
+                        help='手动标注时略微多框了 1~3 像素，使得框“略微越界”，但仍然可以认为是属于该人，默认2像素，值越小正确率越高')
     parser.add_argument('--judging-flags', type=ast.literal_eval, help="检查flags默认标注属性，是否符合标注准则")
     parser.add_argument('--judging-label', type=str, help="检查车牌默认分组属性，是否符合标注准则，车牌一定要打组，如果没有打组就筛选出来")
     parser.add_argument('--judging-polygon', type=int, help='检查多边形标注的点是否超出预期数量，比如4个点的多边形，不能出现5个')
@@ -53,12 +67,21 @@ def parser_args():
     parser.add_argument('--threshold', type=float, help="阈值参数，模型预测数据集，设定的阈值")
     parser.add_argument('--leak-check', action="store_true", help="默认False，填写参数代表为true，用于筛选漏检出数据。是为True，否为False")
     parser.add_argument('--randomize', action="store_true", help="默认False，填写参数代表为true，用于列表随机化。是为True，否为False")
-    parser.add_argument('--test-ratio', type=float, default=0.2, help='默认测试集比例值')
+    parser.add_argument('--test-ratio', type=float, default=0.1, help='默认测试集比例值')
+    parser.add_argument('--val-ratio', type=float, default=0.1, help='默认测试集比例值')
     parser.add_argument('--train-ratio', type=float, default=0.8, help='默认训练集比例值')
+    parser.add_argument('--small-ratio', type=float, default=0.01, help='默认小目标比例')
+    parser.add_argument('--medium-ratio', type=float, default=0.1, help='默认中目标比例')
     parser.add_argument('--error-check', action="store_true", help="默认False，填写参数代表为true，用于筛选误检出数据。是为True，否为False")
     parser.add_argument('--right-check', action="store_true", help="默认False，填写参数代表为true，用于筛选正确检出数据。是为True，否为False")
+    # parser.add_argument('--error-check', action="store_true", help="默认False，填写参数代表为true，用于筛选正确检出数据。是为True，否为False")
     parser.add_argument('--coco-to-bbox', action="store_true", help="默认False，填写参数代表为true，用于判断多边形转矩形框。是为True，否为False")
     parser.add_argument('--background', action="store_true", help="默认False，填写参数代表为true，用于把系统输出的json转换为labelme对应的json。是为True，否为False")
+    parser.add_argument('--choose-more', action="store_true",
+                        help="默认False，填写参数代表为true，用于获取更多数据，包含通道阻塞和通道占用，不填写则只获取通道占用数据。是为True，否为False")
+    parser.add_argument('--choose_polygon', action="store_true", help="默认False，填写参数代表为true，不填写代表不保存多边形，填写则保存多边形。是为True，否为False")
+    parser.add_argument('--fill-rules', action="store_true", help="默认False，填写参数代表为true，用于判断是否为chipeak系统上报数据")
+    parser.add_argument('--statistics-check', action="store_true", help="默认False，填写参数代表为true，用于统计结果勾选记录")
     parser.add_argument('--is-PCA', action="store_true",
                         help="默认False，填写参数代表为true，用于直方图降维条件判断。是为True，但会造成信息丢失，否为False，信息更准确")
     parser.add_argument('--delete', action="store_true", help="默认False，填写参数代表为true，用于删除勾选数据。是为True，否为False")
@@ -70,6 +93,12 @@ def parser_args():
     parser.add_argument('--helmet-false', type=str, help="分类目录规则，no_select")
     parser.add_argument('--mv5-value', type=str, help="分类目录规则，no_select")
     parser.add_argument('--flags-value', type=ast.literal_eval, help="填写flags的字典值")
+    parser.add_argument('--fields', type=str, help="csv文件某列字段")
+    parser.add_argument('--intercept-the-object', type=str, help="填写指定截取标注对象的标签名称")
+    parser.add_argument('--slice-width', type=int, help="切图宽度")
+    parser.add_argument('--slice-height', type=int, help="切图高度")
+    parser.add_argument('--conf', type=float, help="置信度分数")
+    parser.add_argument('--stride', type=int, help="滑动步长，推荐50%重叠")
     parser.add_argument('--image-check', action="store_true",
                         help="默认False，填写参数代表为true即开启检查功能并移除图像，用于检查图像格式、通道、完整性及其它问题。是为True，否为False")
     args = parser.parse_args()
@@ -109,6 +138,8 @@ def parser_args():
         return args
     elif args.function == 'check_image_path':  # 检查标注路径
         return args
+    elif args.function == 'save_chipeak_data':  # 处理save_chipeak_data
+        return args
     elif args.function == 'delete':  # 按照标注标签删除标注
         return args
     elif args.function == 'extract':  # 抽取labelme数据集，包含按照指定份数抽取，按照图像张数抽取，可以拷贝、剪切
@@ -165,6 +196,30 @@ def parser_args():
         return args
     elif args.function == 'category_name':  # 打印分类类别名称
         return args
+    elif args.function == 'optimize':  # 优化截取车和车牌标注逻辑算法
+        return args
+    elif args.function == 'excel':  # 提取excel表格某列数据的url地址，并下载
+        return args
+    elif args.function == 'file_name':  # 同步重命名文件名称
+        return args
+    elif args.function == 'draw_video':  # 图片合并视频并绘制标注属性
+        return args
+    elif args.function == 'blacked':  # 目标矩形框涂黑操作
+        return args
+    elif args.function == 'csv':  # csv文件处理，提前某列字段数据
+        return args
+    elif args.function == 'sahi':  # 滑窗切图
+        return args
+    elif args.function == 'intercept':  # 截取标注的人矩形框图片，并包含在内的其它矩形框标注
+        return args
+    elif args.function == 'mix':  # 计算标注目标与图像面积占比，划分保留大、中、小、的标注目标为labelme数据集功能。
+        return args
+    elif args.function == 'sampling':  # 目标检测，标注数据的标签采样功能
+        return args
+    elif args.function == 'pixel_filtering':  # 筛选指定像素高宽比例的标注
+        return args
+    elif args.function == 'confidence':  # 筛选并移动指定阈值的labelme数据集
+        return args
     else:
         assert not args.function, '传入的操作功能参数不对:{}'.format(args.function)
 
@@ -185,18 +240,26 @@ def main():
             print(time.time() - async_time)
         if args.function == 'pinyin':
             data_info.hanzi_to_pinyin()  # 对中文路径转拼音后，重新输出
+        if args.function == 'file_name':
+            data_info.rename_file_name()  # 重命名文件名称
         if args.function == 'pinyin_images':
             data_info.hanzi_to_pinyin_images()  # 对中文路径转拼音后，只处理有图像的情况，没有labelme
         if args.function == 'check_format':  # 检查图像格式
             data_info.check_images_format()
         if args.function == 'category_name':  # 检查图像格式
-            data_info.print_icategory_name()
+            data_info.print_icategory_name(args)
+        if args.function == 'excel':  # 获取execl表格某列数据的url地址，并下载
+            data_info.get_excel_url_data(args)
+        elif args.function == 'ratio':  # 火柴人图像，按比例划分测试集和训练集
+            data_info.ratio_split(args)
+        elif args.function == 'csv':  # 获取csv文件中的url地址数据
+            data_info.extract_fields_csv(args)
 
     else:  # 异步读写数据处理，存在少部分同步写数据处理
         async_time = time.time()
         data_info = LabelmeLoad(args, input_datasets_list)  # 初始化输入参数
         # 获取当前正在运行的事件循环，从而可以将异步任务添加到事件循环中执行。在等待IO操作完成的同时，利用CPU计算力进行其他计算，从而提高计算效率
-        dataset_info = asyncio.run(data_info.recursive_walk(input_datasets_list[0].get('input_dir'), args.function))
+        dataset_info = asyncio.run(data_info.recursive_walk(input_datasets_list[0].get('input_dir'), args))
         print('数据读取使用异步计算耗时')
         print(time.time() - async_time)
         dataset = BaseLabelme(dataset_info)  # 初始化labelme基类
@@ -208,10 +271,12 @@ def main():
                 # original_dataset_info = dataset.del_label(args.del_label)
                 dataset.labelme_rectangle_merge(args, model_dataset_info)
             else:
-                dataset.merge_labelme(args)  # 人工标注数据，根据label拆分后，自动合并实现功能
+                dataset.merge_labelme(args)  # 人工标注数据，根据label拆分后，自动合并实现功能，所有标签合并一起，只要MD5值相同的文件就进行合并。
             # BaseLabelme.merge(datasets)
         elif args.function == 'matting':  # 抠出标注位置保存labelme
             dataset.intercept_coordinates()
+        elif args.function == 'optimize':  # 车和车牌标注优化
+            dataset.intercept_coordinates_optimize()
         elif args.function == 'duplicate':  # 对labelme数据集进行去重，重复的图片就删除
             dataset.duplicate_images()
         elif args.function == 'crop':
@@ -233,7 +298,28 @@ def main():
                 txt.txt2labelme()
             elif args.output_format == 'sys':  # 把系统输出格式，转换为labelme标注工具可读格式。
                 sys = BaseSys(dataset_info, args)
-                sys.sys2labelme()
+                sys.sys2labelme(args)
+            elif args.output_format == 'newbie':  # 把系统输出格式，转换为labelme标注工具可读格式。
+                sys = BaseSys(dataset_info, args)
+                sys.newbie2labelme()
+            elif args.output_format == 'polygon':  # 把多边形坐标写入labelme
+                sys = BaseSys(dataset_info, args)
+                sys.polygon2labelme()
+            elif args.output_format == 'excel':  # 把except表格自动填充图片和车牌号
+                sys = BaseSys(dataset_info, args)
+                sys.labelme2excel()
+            elif args.output_format == 'xml':  # 把labelme转xml格式，即VOC
+                xml = BaseXml(dataset_info, args)
+                xml.labelme2xml()
+            elif args.output_format == 'yolo':  # 把labelme转yolo格式
+                yolo = BaseYolo(dataset_info, args)
+                yolo.labelme2yolo()
+            elif args.output_format == 'csv':  # 把labelme转csv格式
+                csv = BaseCsv(dataset_info, args)
+                csv.labelme2csv()
+            elif args.output_format == 'yolo_to_labelme':  # yolo转labelme
+                voc = BaseYolo(dataset_info, args)
+                voc.yolo2labelme()
         elif args.function == 'rename':  # 重命名label标签功能
             dataset.rename_labelme(args)
             # dataset.save_labelme(args.output_dir, None, None)
@@ -253,6 +339,8 @@ def main():
             dataset.__repr__()
         elif args.function == 'check_image_path':  # 检查image_path功能
             dataset.check_image_path(args)
+        elif args.function == 'save_chipeak_data':  # 检查image_path功能
+            dataset.save_chipeak_data(args)
         elif args.function == 'delete':  # 删除指定标签类别标注数据集
             dataset.del_label(args.del_label)
             print(f'保存指定label类别进行删除的labelme数据集')
@@ -318,9 +406,23 @@ def main():
         elif args.function == 'filter_flags_true':  # 筛选falgs值为真的标注
             dataset.select_flags_true(args)
         elif args.function == 'ratio':  # 按比例划分测试集和训练集
-            dataset.ratio_split(args)
-
-
+            dataset.ratio_split_three(args)
+        elif args.function == 'draw_video':  # 根据图片合成视频并绘制标注内容
+            dataset.draw_video(args)
+        elif args.function == 'blacked':  # 把通道占用抽取的数据中的矩形框涂黑
+            dataset.blacked_images()
+        elif args.function == 'sahi':  # 滑窗切图
+            dataset.sahi_images(args)
+        elif args.function == 'intercept':  # 截取标注的人矩形框图片，并包含在内的其它矩形框标注
+            dataset.intercept_images(args)
+        elif args.function == 'mix':  # 计算标注目标与图像面积占比，划分保留大、中、小、的标注目标为labelme数据集功能。
+            dataset.mix_images(args)
+        elif args.function == 'sampling':  # 目标检测，标注数据的标签采样功能
+            dataset.sampling_images(args)
+        elif args.function == 'pixel_filtering':  # 筛选指定像素高宽比例的标注数据
+            dataset.pixel_filtering(args)
+        elif args.function == 'confidence':  # 筛选移动指定置信度labelme数据
+            dataset.confidence_filtering(args)
 if __name__ == '__main__':
     main()
     # 使用了asyncio.run()函数来启动，协程事件循环，则不需要手动关闭事件循环
